@@ -3,7 +3,7 @@ from df2onehot.df2onehot import (
     import_example,
     )
 
-from df2onehot.set_dtypes import (
+from df2onehot.utils import (
  	set_dtypes,
  	is_DataFrame,
     set_y,
@@ -11,7 +11,7 @@ from df2onehot.set_dtypes import (
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '0.2.14'
+__version__ = '0.2.16'
 
 # module level doc-string
 __doc__ = """
